---
title: <span class="badge object-type-enum"></span> MetricFindQueryTypes
---
# <span class="badge object-type-enum"></span> MetricFindQueryTypes

## Definition

```python
class MetricFindQueryTypes(enum.StrEnum):
    PROJECTS = "projects"
    SERVICES = "services"
    DEFAULT_PROJECT = "defaultProject"
    METRIC_TYPES = "metricTypes"
    LABEL_KEYS = "labelKeys"
    LABEL_VALUES = "labelValues"
    RESOURCE_TYPES = "resourceTypes"
    AGGREGATIONS = "aggregations"
    ALIGNERS = "aligners"
    ALIGNMENT_PERIODS = "alignmentPeriods"
    SELECTORS = "selectors"
    SLO_SERVICES = "sloServices"
    SLO = "slo"
```
